/*************************************************************/
// Copyright (c) 2020 Oracle and/or its affiliates.
/*************************************************************/

output "namespace" {
  value = data.oci_objectstorage_namespace.ns.namespace
}

output "sbc_public_ip" {
  value = oci_core_instance.sbc_instance[*].public_ip
}

output "sbc_private_ip" {
  value = oci_core_instance.sbc_instance[*].private_ip
}

output "sbc_details" {
  value = [for i in range(local.num_instances) : {
    name        = oci_core_instance.sbc_instance[i].display_name
    instance_id = oci_core_instance.sbc_instance[i].id

    public_ip  = oci_core_instance.sbc_instance[i].public_ip
    private_ip = oci_core_instance.sbc_instance[i].private_ip

    par_metadata = "https://objectstorage.${var.region}.oraclecloud.com${oci_objectstorage_preauthrequest.par_metadata[i].access_uri}"
    par_userdata = "https://objectstorage.${var.region}.oraclecloud.com${oci_objectstorage_preauthrequest.par_userdata[i].access_uri}"

    console = local.sshPubKey[1] == "" ? "" : oci_core_instance_console_connection.sbc_instance_console_connection[i].connection_string

    wancom0_ip = data.oci_core_vnic.sbc_vnic_wancom0[i].private_ip_address
    wancom1_ip = local.wancom1_vnic_count != 2 ? "" : data.oci_core_vnic.sbc_vnic_wancom1[i].private_ip_address
    wancom2_ip = local.wancom2_vnic_count != 2 ? "" : data.oci_core_vnic.sbc_vnic_wancom2[i].private_ip_address

    s0p0_ip = local.s0p0_vnic_count == 0 ? "" : data.oci_core_vnic.sbc_vnic_s0p0[i].private_ip_address
    s1p0_ip = local.s1p0_vnic_count == 0 ? "" : data.oci_core_vnic.sbc_vnic_s1p0[i].private_ip_address
    s0p1_ip = local.s0p1_vnic_count == 0 ? "" : data.oci_core_vnic.sbc_vnic_s0p1[i].private_ip_address
    s1p1_ip = local.s1p1_vnic_count == 0 ? "" : data.oci_core_vnic.sbc_vnic_s1p1[i].private_ip_address

    s0p0_virtual_ips = local.s0p0_vnic_count != 2 ? [] : oci_core_private_ip.sbc_s0p0_vips[*].ip_address
    s1p0_virtual_ips = local.s1p0_vnic_count != 2 ? [] : oci_core_private_ip.sbc_s1p0_vips[*].ip_address
    s0p1_virtual_ips = local.s0p1_vnic_count != 2 ? [] : oci_core_private_ip.sbc_s0p1_vips[*].ip_address
    s1p1_virtual_ips = local.s1p1_vnic_count != 2 ? [] : oci_core_private_ip.sbc_s1p1_vips[*].ip_address

    s0p0_reserved_public_ips = local.s0p0_public_ip_count == 0 ? [] : oci_core_public_ip.sbc_s0p0_public_ip[*].ip_address
    s1p0_reserved_public_ips = local.s1p0_public_ip_count == 0 ? [] : oci_core_public_ip.sbc_s1p0_public_ip[*].ip_address
    s0p1_reserved_public_ips = local.s0p1_public_ip_count == 0 ? [] : oci_core_public_ip.sbc_s0p1_public_ip[*].ip_address
    s1p1_reserved_public_ips = local.s1p1_public_ip_count == 0 ? [] : oci_core_public_ip.sbc_s1p1_public_ip[*].ip_address

    user_data = local.template_vars[i]
    meta_data = local.metadata[i]
  }]
}
